#####################################
Novanta FPU60 laser power supply unit
#####################################

.. autoclass:: pymeasure.instruments.novanta.Fpu60
    :members:
    :show-inheritance:
